"""
Random User-Agent
Copyright: 2022-2024 Ekin Karadeniz (github.com/iamdual)
License: Apache License 2.0
"""


class CannotGenerateError(Exception):
    pass


class InvalidArgumentError(Exception):
    pass
